# MSKit

A tool-kit for MS data (pre-)processing

Extracted from part of code used in personal data analysis. 
Though there is no document and description, 
the name of each module is defined clear (think so). 
If you find some functions are useful, please feel free to copy them and use.
If you read the code of this package and find error or have suggestions, 
please also contact with me and I'll be pleased to improve them.

The recommended modules are
* TED (theoretical enzyme digestion/ in-silico digestion)
* SpectronautLibrary (to process Spectronaut library with pre-defined useful functions)
* Functions in rapik_kit (many easy-to-use tools to save much time)
* mass_calc (supports the mass/mz calculation for peptides with no modification or some common modifications)
